@@ -258,10 +258,8 @@ impl TerserCompressorOptions {
             bools_as_ints: self.booleans_as_integers,
             collapse_vars: self.collapse_vars.unwrap_or(self.defaults),
             comparisons: self.comparisons.unwrap_or(self.defaults),
-            // TODO: Use self.defaults
-            computed_props: self.computed_props.unwrap_or(false),
-            // TODO: Use self.defaults
-            conditionals: self.conditionals.unwrap_or(false),
+            computed_props: self.computed_props.unwrap_or(self.defaults),
+            conditionals: self.conditionals.unwrap_or(self.defaults),
             dead_code: self.dead_code.unwrap_or(self.defaults),
             directives: self.directives.unwrap_or(self.defaults),
             drop_console: self.drop_console,
